================
motechjavasphinx
================

motechjavasphinx is an extension to the Sphinx documentation system which adds support
for executing javasphinx during the sphinx build.  The extension searches project poms
for packages exported through OSGi and only executes javasphinx on those classes.
